<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:d="http://docbook.org/ns/docbook"
  xmlns:m="http://www.w3.org/1998/Math/MathML"
  xmlns="http://www.w3.org/1999/xhtml"
  exclude-result-prefixes="d xs m"
  version="2.0">
  
  <xsl:import href="path.xsl"/>
  
  <xsl:variable name="n">
    <xsl:text>
</xsl:text>
  </xsl:variable>
  
  <xsl:template mode="idConcatPosition" match="*">
    <xsl:param name="baseId"/>
    
    <xsl:choose>
      
      <xsl:when test="1 = position()">
        <xsl:value-of select="$baseId"/>
      </xsl:when>
      
      <xsl:otherwise>
        <xsl:value-of select="concat($baseId, '-', position() - 1)"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template mode="id_or_generate_id" match="*">
    <xsl:choose>
      
      <xsl:when test="@xml:id">
        <xsl:value-of select="@xml:id"/>
      </xsl:when>
      
      <xsl:otherwise>
        <xsl:value-of select="generate-id(.)"/>
      </xsl:otherwise>
      
    </xsl:choose>
  </xsl:template>
  
  <xsl:param name="toggleDisplayScript">
    <script src="docbooksupplement.js"></script>
  </xsl:param>
  
  <!--Allow for opening and closing of answers -->  
  <xsl:template match="d:answer" priority="1">
    <xsl:variable name="deflabel">
      <xsl:apply-templates select="." mode="qanda.defaultlabel"/>
    </xsl:variable>
    
    <tr>
      <xsl:apply-templates select="." mode="common.html.attributes"/>
      <xsl:call-template name="id.attribute"/>
      <td align="{$direction.align.start}" valign="top">
        <xsl:call-template name="anchor"/>
        <xsl:variable name="answer.label">
          <xsl:apply-templates select="." mode="label.markup"/>
        </xsl:variable>
        <xsl:if test="string-length($answer.label) &gt; 0">
          <p><strong>
            <xsl:copy-of select="$answer.label"/>
          </strong></p>
        </xsl:if>
      </td>
      <td align="{$direction.align.start}" valign="top">
        <input class="hideSolution" type="button" /> <!--goik: start "header" clickable answer modification -->
        <div>                                        <!--goik: end "header" clickable answer modification -->
          <xsl:apply-templates select="*[local-name(.) != 'label'         and local-name(.) != 'qandaentry']"/>
          <!-- * handle nested answer/qandaentry instances -->
          <!-- * (bug 1509043 from Daniel Leidert) -->
          <xsl:if test="descendant::d:question">
            <xsl:call-template name="process.qandaset"/>
          </xsl:if>
        </div>                                                         <!--goik: "footer" clickable answer modification -->        
      </td>
    </tr>
  </xsl:template>
  
  <!-- avoid namespace prefix since some epub readers get confused. Credits to
    http://stackoverflow.com/questions/16810039/how-to-remove-namespace-prefix-leaving-namespace-value-xslt
  -->
  <xsl:template match="m:math[not(@alttext)]" priority="2">
    <xsl:element name="{local-name()}" namespace="http://www.w3.org/1998/Math/MathML">
      <xsl:attribute name="alttext">math formula</xsl:attribute>
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>
  
  <xsl:template match="m:*" priority="1">
    <xsl:element name="{local-name()}" namespace="http://www.w3.org/1998/Math/MathML">
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>

  <!-- Fixing Docbook dbhtml-include Xinclude bug -->

  <xsl:template name="pi.dbhtml-include">
    <xsl:param name="href">
      <xsl:for-each select="ancestor::*/@xml:base">
        <xsl:call-template name="hdm.get.leftmost.of.separator">
          <xsl:with-param name="path">
            <xsl:value-of select="."/>
          </xsl:with-param>
          <xsl:with-param name="separator">/</xsl:with-param>
        </xsl:call-template>
        <xsl:text>/</xsl:text>
      </xsl:for-each>
      <xsl:call-template name="dbhtml-attribute">
        <xsl:with-param name="pis" select="."/>
        <xsl:with-param name="attribute">href</xsl:with-param>
      </xsl:call-template>
    </xsl:param>

    <xsl:choose>
      <xsl:when test="$href != ''">
        <xsl:variable name="content" select="document($href,/)"/>
        <xsl:choose>
          <xsl:when test="$content/*">
            <xsl:choose>
              <xsl:when test="$content/*[1][self::html]">
                <!-- include just the children of html wrapper -->
                <xsl:copy-of select="$content/*[1]/node()"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:copy-of select="$content"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:otherwise>
            <xsl:message>
              <xsl:text>ERROR: dbhtml-include processing instruction </xsl:text>
              <xsl:text>href has no content.</xsl:text>
            </xsl:message>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:message>
          <xsl:text>ERROR: dbhtml-include processing instruction has </xsl:text>
          <xsl:text>missing or empty href value.</xsl:text>
        </xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
</xsl:stylesheet>
